# Nodequelize
Nodequelize is a NodeJS REST API generator powered by Express and Sequelize. It uses a simple configuration file that lets you define your entities, database connection settings and other options to create a fully functional CRUD (Create, Read, Update and Delete) REST API that you can start using immediately.

## Why Nodequelize?
I like Sequelize because it makes my life easier. I like Express because it creates great APIs. I don't like repeating myself too much or making the same CRUD methods over and over again for different entities. Nodequelize tries to automate this process and make my life easier, and hopefully yours, too!

## Current and future features
- [x] Create a NodeJS + Express + Sequelize API structure automatically
- [ ] Create CRUD models, controllers and routes for your entities in a project
- [ ] Create individual CRUD entities without creating a whole project 
- [ ] Basic Auth endpoint authentication
- [ ] JSON Web Tokens (JWT) endpoint authentication
- [ ] Create paginated searches for big data sources
- [ ] Create automatic FULLTEXT searches
- [ ] Automatically create API documentation in a README
- [ ] Have special cases for CRUD entities (for example, User entity with special endpoints)

## Usage
### Create an API from scratch
- Install nodequelize globally with `npm install -g nodequelize`
- `cd` into the directory where you want your API created **(be careful where you run the command, as it will replace preexisting files)**
- Create a new JSON file in this directory and call it `my_api_settings.json`
- Add the settings of your API with the following structure:
```
{
    "port": "9000",
    "api_route": "api",
    "package_info": {
        "name": "my-api",
        "version": "1.0.0",
        "description": "My new API, generated by Nodequelize",
        "author": "Nodequelize"
    },
    "database_config": {
        "prod": {
            "username": "username-prod",
            "password": "password-prod",
            "database": "database-prod",
            "host": "host-prod",
            "port": "port-prod",
            "dialect": "mssql"
        },
        "dev": {
            "username": "username-dev",
            "password": "password-dev",
            "database": "database-dev",
            "host": "host-dev",
            "port": "port-dev",
            "dialect": "mssql"
        }
    }
}
```
- Generate your API with `nodequelize create_project my_api_settings.json`
- Install the API dependencies with `npm install`
- Run your API with `npm start`
- Go to your browser and access `http://localhost:9000/api`, you should see a message indicating that it's working!

### License
This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program.  If not, see <http://www.gnu.org/licenses/>.